pub enum BlockState {
Show 681 variants
AcaciaButton {
face: AttachFace,
facing: HorizontalDirection,
powered: bool,
},
AcaciaDoor {
facing: HorizontalDirection,
half: DoubleBlockHalf,
hinge: DoorHingeSide,
open: bool,
powered: bool,
},
AcaciaFence {
east: bool,
north: bool,
south: bool,
waterlogged: bool,
west: bool,
},
AcaciaFenceGate {
facing: HorizontalDirection,
in_wall: bool,
open: bool,
powered: bool,
},
AcaciaLeaves {
distance: BoundedU8<1, 7>,
persistent: bool,
},
AcaciaLog {
axis: Axis,
},
AcaciaPlanks,
AcaciaPressurePlate {
powered: bool,
},
AcaciaSapling {
stage: BoundedU8<0, 1>,
},
AcaciaSign {
rotation: BoundedU8<0, 15>,
waterlogged: bool,
},
AcaciaSlab {
type: SlabType,
waterlogged: bool,
},
AcaciaStairs {
facing: HorizontalDirection,
half: Half,
shape: StairsShape,
waterlogged: bool,
},
AcaciaTrapdoor {
facing: HorizontalDirection,
half: Half,
open: bool,
powered: bool,
waterlogged: bool,
},
AcaciaWallSign {
facing: HorizontalDirection,
waterlogged: bool,
},
AcaciaWood {
axis: Axis,
},
ActivatorRail {
powered: bool,
shape: StraightRailShape,
},
Air,
Allium,
Andesite,
AndesiteSlab {
type: SlabType,
waterlogged: bool,
},
AndesiteStairs {
facing: HorizontalDirection,
half: Half,
shape: StairsShape,
waterlogged: bool,
},
AndesiteWall {
east: bool,
north: bool,
south: bool,
up: bool,
waterlogged: bool,
west: bool,
},
Anvil {
facing: HorizontalDirection,
},
AttachedMelonStem {
facing: HorizontalDirection,
},
AttachedPumpkinStem {
facing: HorizontalDirection,
},
AzureBluet,
Bamboo {
age: BoundedU8<0, 1>,
leaves: BambooLeaves,
stage: BoundedU8<0, 1>,
},
BambooSapling,
Barrel {
facing: Direction,
open: bool,
},
Barrier,
Beacon,
Bedrock,
BeeNest {
facing: HorizontalDirection,
honey_level: BoundedU8<0, 5>,
},
Beehive {
facing: HorizontalDirection,
honey_level: BoundedU8<0, 5>,
},
Beetroots {
age: BoundedU8<0, 3>,
},
Bell {
attachment: BellAttachType,
facing: HorizontalDirection,
powered: bool,
},
BirchButton {
face: AttachFace,
facing: HorizontalDirection,
powered: bool,
},
BirchDoor {
facing: HorizontalDirection,
half: DoubleBlockHalf,
hinge: DoorHingeSide,
open: bool,
powered: bool,
},
BirchFence {
east: bool,
north: bool,
south: bool,
waterlogged: bool,
west: bool,
},
BirchFenceGate {
facing: HorizontalDirection,
in_wall: bool,
open: bool,
powered: bool,
},
BirchLeaves {
distance: BoundedU8<1, 7>,
persistent: bool,
},
BirchLog {
axis: Axis,
},
BirchPlanks,
BirchPressurePlate {
powered: bool,
},
BirchSapling {
stage: BoundedU8<0, 1>,
},
BirchSign {
rotation: BoundedU8<0, 15>,
waterlogged: bool,
},
BirchSlab {
type: SlabType,
waterlogged: bool,
},
BirchStairs {
facing: HorizontalDirection,
half: Half,
shape: StairsShape,
waterlogged: bool,
},
BirchTrapdoor {
facing: HorizontalDirection,
half: Half,
open: bool,
powered: bool,
waterlogged: bool,
},
BirchWallSign {
facing: HorizontalDirection,
waterlogged: bool,
},
BirchWood {
axis: Axis,
},
BlackBanner {
rotation: BoundedU8<0, 15>,
},
BlackBed {
facing: HorizontalDirection,
occupied: bool,
part: BedPart,
},
BlackCarpet,
BlackConcrete,
BlackConcretePowder,
BlackGlazedTerracotta {
facing: HorizontalDirection,
},
BlackShulkerBox {
facing: Direction,
},
BlackStainedGlass,
BlackStainedGlassPane {
east: bool,
north: bool,
south: bool,
waterlogged: bool,
west: bool,
},
BlackTerracotta,
BlackWallBanner {
facing: HorizontalDirection,
},
BlackWool,
BlastFurnace {
facing: HorizontalDirection,
lit: bool,
},
BlueBanner {
rotation: BoundedU8<0, 15>,
},
BlueBed {
facing: HorizontalDirection,
occupied: bool,
part: BedPart,
},
BlueCarpet,
BlueConcrete,
BlueConcretePowder,
BlueGlazedTerracotta {
facing: HorizontalDirection,
},
BlueIce,
BlueOrchid,
BlueShulkerBox {
facing: Direction,
},
BlueStainedGlass,
BlueStainedGlassPane {
east: bool,
north: bool,
south: bool,
waterlogged: bool,
west: bool,
},
BlueTerracotta,
BlueWallBanner {
facing: HorizontalDirection,
},
BlueWool,
BoneBlock {
axis: Axis,
},
Bookshelf,
BrainCoral {
waterlogged: bool,
},
BrainCoralBlock,
BrainCoralFan {
waterlogged: bool,
},
BrainCoralWallFan {
facing: HorizontalDirection,
waterlogged: bool,
},
BrewingStand {
has_bottle_0: bool,
has_bottle_1: bool,
has_bottle_2: bool,
},
BrickSlab {
type: SlabType,
waterlogged: bool,
},
BrickStairs {
facing: HorizontalDirection,
half: Half,
shape: StairsShape,
waterlogged: bool,
},
BrickWall {
east: bool,
north: bool,
south: bool,
up: bool,
waterlogged: bool,
west: bool,
},
Bricks,
BrownBanner {
rotation: BoundedU8<0, 15>,
},
BrownBed {
facing: HorizontalDirection,
occupied: bool,
part: BedPart,
},
BrownCarpet,
BrownConcrete,
BrownConcretePowder,
BrownGlazedTerracotta {
facing: HorizontalDirection,
},
BrownMushroom,
BrownMushroomBlock {
down: bool,
east: bool,
north: bool,
south: bool,
up: bool,
west: bool,
},
BrownShulkerBox {
facing: Direction,
},
BrownStainedGlass,
BrownStainedGlassPane {
east: bool,
north: bool,
south: bool,
waterlogged: bool,
west: bool,
},
BrownTerracotta,
BrownWallBanner {
facing: HorizontalDirection,
},
BrownWool,
BubbleColumn {
drag: bool,
},
BubbleCoral {
waterlogged: bool,
},
BubbleCoralBlock,
BubbleCoralFan {
waterlogged: bool,
},
BubbleCoralWallFan {
facing: HorizontalDirection,
waterlogged: bool,
},
Cactus {
age: BoundedU8<0, 15>,
},
Cake {
bites: BoundedU8<0, 6>,
},
Campfire {
facing: HorizontalDirection,
lit: bool,
signal_fire: bool,
waterlogged: bool,
},
Carrots {
age: BoundedU8<0, 7>,
},
CartographyTable,
CarvedPumpkin {
facing: HorizontalDirection,
},
Cauldron {
level: BoundedU8<0, 3>,
},
CaveAir,
ChainCommandBlock {
conditional: bool,
facing: Direction,
},
Chest {
facing: HorizontalDirection,
type: ChestType,
waterlogged: bool,
},
ChippedAnvil {
facing: HorizontalDirection,
},
ChiseledQuartzBlock,
ChiseledRedSandstone,
ChiseledSandstone,
ChiseledStoneBricks,
ChorusFlower {
age: BoundedU8<0, 5>,
},
ChorusPlant {
down: bool,
east: bool,
north: bool,
south: bool,
up: bool,
west: bool,
},
Clay,
CoalBlock,
CoalOre,
CoarseDirt,
Cobblestone,
CobblestoneSlab {
type: SlabType,
waterlogged: bool,
},
CobblestoneStairs {
facing: HorizontalDirection,
half: Half,
shape: StairsShape,
waterlogged: bool,
},
CobblestoneWall {
east: bool,
north: bool,
south: bool,
up: bool,
waterlogged: bool,
west: bool,
},
Cobweb,
Cocoa {
age: BoundedU8<0, 2>,
facing: HorizontalDirection,
},
CommandBlock {
conditional: bool,
facing: Direction,
},
Comparator {
facing: HorizontalDirection,
mode: ComparatorMode,
powered: bool,
},
Composter {
level: BoundedU8<0, 8>,
},
Conduit {
waterlogged: bool,
},
Cornflower,
CrackedStoneBricks,
CraftingTable,
CreeperHead {
rotation: BoundedU8<0, 15>,
},
CreeperWallHead {
facing: HorizontalDirection,
},
CutRedSandstone,
CutRedSandstoneSlab {
type: SlabType,
waterlogged: bool,
},
CutSandstone,
CutSandstoneSlab {
type: SlabType,
waterlogged: bool,
},
CyanBanner {
rotation: BoundedU8<0, 15>,
},
CyanBed {
facing: HorizontalDirection,
occupied: bool,
part: BedPart,
},
CyanCarpet,
CyanConcrete,
CyanConcretePowder,
CyanGlazedTerracotta {
facing: HorizontalDirection,
},
CyanShulkerBox {
facing: Direction,
},
CyanStainedGlass,
CyanStainedGlassPane {
east: bool,
north: bool,
south: bool,
waterlogged: bool,
west: bool,
},
CyanTerracotta,
CyanWallBanner {
facing: HorizontalDirection,
},
CyanWool,
DamagedAnvil {
facing: HorizontalDirection,
},
Dandelion,
DarkOakButton {
face: AttachFace,
facing: HorizontalDirection,
powered: bool,
},
DarkOakDoor {
facing: HorizontalDirection,
half: DoubleBlockHalf,
hinge: DoorHingeSide,
open: bool,
powered: bool,
},
DarkOakFence {
east: bool,
north: bool,
south: bool,
waterlogged: bool,
west: bool,
},
DarkOakFenceGate {
facing: HorizontalDirection,
in_wall: bool,
open: bool,
powered: bool,
},
DarkOakLeaves {
distance: BoundedU8<1, 7>,
persistent: bool,
},
DarkOakLog {
axis: Axis,
},
DarkOakPlanks,
DarkOakPressurePlate {
powered: bool,
},
DarkOakSapling {
stage: BoundedU8<0, 1>,
},
DarkOakSign {
rotation: BoundedU8<0, 15>,
waterlogged: bool,
},
DarkOakSlab {
type: SlabType,
waterlogged: bool,
},
DarkOakStairs {
facing: HorizontalDirection,
half: Half,
shape: StairsShape,
waterlogged: bool,
},
DarkOakTrapdoor {
facing: HorizontalDirection,
half: Half,
open: bool,
powered: bool,
waterlogged: bool,
},
DarkOakWallSign {
facing: HorizontalDirection,
waterlogged: bool,
},
DarkOakWood {
axis: Axis,
},
DarkPrismarine,
DarkPrismarineSlab {
type: SlabType,
waterlogged: bool,
},
DarkPrismarineStairs {
facing: HorizontalDirection,
half: Half,
shape: StairsShape,
waterlogged: bool,
},
DaylightDetector {
inverted: bool,
power: BoundedU8<0, 15>,
},
DeadBrainCoral {
waterlogged: bool,
},
DeadBrainCoralBlock,
DeadBrainCoralFan {
waterlogged: bool,
},
DeadBrainCoralWallFan {
facing: HorizontalDirection,
waterlogged: bool,
},
DeadBubbleCoral {
waterlogged: bool,
},
DeadBubbleCoralBlock,
DeadBubbleCoralFan {
waterlogged: bool,
},
DeadBubbleCoralWallFan {
facing: HorizontalDirection,
waterlogged: bool,
},
DeadBush,
DeadFireCoral {
waterlogged: bool,
},
DeadFireCoralBlock,
DeadFireCoralFan {
waterlogged: bool,
},
DeadFireCoralWallFan {
facing: HorizontalDirection,
waterlogged: bool,
},
DeadHornCoral {
waterlogged: bool,
},
DeadHornCoralBlock,
DeadHornCoralFan {
waterlogged: bool,
},
DeadHornCoralWallFan {
facing: HorizontalDirection,
waterlogged: bool,
},
DeadTubeCoral {
waterlogged: bool,
},
DeadTubeCoralBlock,
DeadTubeCoralFan {
waterlogged: bool,
},
DeadTubeCoralWallFan {
facing: HorizontalDirection,
waterlogged: bool,
},
DetectorRail {
powered: bool,
shape: StraightRailShape,
},
DiamondBlock,
DiamondOre,
Diorite,
DioriteSlab {
type: SlabType,
waterlogged: bool,
},
DioriteStairs {
facing: HorizontalDirection,
half: Half,
shape: StairsShape,
waterlogged: bool,
},
DioriteWall {
east: bool,
north: bool,
south: bool,
up: bool,
waterlogged: bool,
west: bool,
},
Dirt,
Dispenser {
facing: Direction,
triggered: bool,
},
DragonEgg,
DragonHead {
rotation: BoundedU8<0, 15>,
},
DragonWallHead {
facing: HorizontalDirection,
},
DriedKelpBlock,
Dropper {
facing: Direction,
triggered: bool,
},
EmeraldBlock,
EmeraldOre,
EnchantingTable,
EndGateway,
EndPortal,
EndPortalFrame {
eye: bool,
facing: HorizontalDirection,
},
EndRod {
facing: Direction,
},
EndStone,
EndStoneBrickSlab {
type: SlabType,
waterlogged: bool,
},
EndStoneBrickStairs {
facing: HorizontalDirection,
half: Half,
shape: StairsShape,
waterlogged: bool,
},
EndStoneBrickWall {
east: bool,
north: bool,
south: bool,
up: bool,
waterlogged: bool,
west: bool,
},
EndStoneBricks,
EnderChest {
facing: HorizontalDirection,
waterlogged: bool,
},
Farmland {
moisture: BoundedU8<0, 7>,
},
Fern,
Fire {
age: BoundedU8<0, 15>,
east: bool,
north: bool,
south: bool,
up: bool,
west: bool,
},
FireCoral {
waterlogged: bool,
},
FireCoralBlock,
FireCoralFan {
waterlogged: bool,
},
FireCoralWallFan {
facing: HorizontalDirection,
waterlogged: bool,
},
FletchingTable,
FlowerPot,
FrostedIce {
age: BoundedU8<0, 3>,
},
Furnace {
facing: HorizontalDirection,
lit: bool,
},
Glass,
GlassPane {
east: bool,
north: bool,
south: bool,
waterlogged: bool,
west: bool,
},
Glowstone,
GoldBlock,
GoldOre,
Granite,
GraniteSlab {
type: SlabType,
waterlogged: bool,
},
GraniteStairs {
facing: HorizontalDirection,
half: Half,
shape: StairsShape,
waterlogged: bool,
},
GraniteWall {
east: bool,
north: bool,
south: bool,
up: bool,
waterlogged: bool,
west: bool,
},
Grass,
GrassBlock {
snowy: bool,
},
GrassPath,
Gravel,
GrayBanner {
rotation: BoundedU8<0, 15>,
},
GrayBed {
facing: HorizontalDirection,
occupied: bool,
part: BedPart,
},
GrayCarpet,
GrayConcrete,
GrayConcretePowder,
GrayGlazedTerracotta {
facing: HorizontalDirection,
},
GrayShulkerBox {
facing: Direction,
},
GrayStainedGlass,
GrayStainedGlassPane {
east: bool,
north: bool,
south: bool,
waterlogged: bool,
west: bool,
},
GrayTerracotta,
GrayWallBanner {
facing: HorizontalDirection,
},
GrayWool,
GreenBanner {
rotation: BoundedU8<0, 15>,
},
GreenBed {
facing: HorizontalDirection,
occupied: bool,
part: BedPart,
},
GreenCarpet,
GreenConcrete,
GreenConcretePowder,
GreenGlazedTerracotta {
facing: HorizontalDirection,
},
GreenShulkerBox {
facing: Direction,
},
GreenStainedGlass,
GreenStainedGlassPane {
east: bool,
north: bool,
south: bool,
waterlogged: bool,
west: bool,
},
GreenTerracotta,
GreenWallBanner {
facing: HorizontalDirection,
},
GreenWool,
Grindstone {
face: AttachFace,
facing: HorizontalDirection,
},
HayBlock {
axis: Axis,
},
HeavyWeightedPressurePlate {
power: BoundedU8<0, 15>,
},
HoneyBlock,
HoneycombBlock,
Hopper {
enabled: bool,
facing: HopperDirection,
},
HornCoral {
waterlogged: bool,
},
HornCoralBlock,
HornCoralFan {
waterlogged: bool,
},
HornCoralWallFan {
facing: HorizontalDirection,
waterlogged: bool,
},
Ice,
InfestedChiseledStoneBricks,
InfestedCobblestone,
InfestedCrackedStoneBricks,
InfestedMossyStoneBricks,
InfestedStone,
InfestedStoneBricks,
IronBars {
east: bool,
north: bool,
south: bool,
waterlogged: bool,
west: bool,
},
IronBlock,
IronDoor {
facing: HorizontalDirection,
half: DoubleBlockHalf,
hinge: DoorHingeSide,
open: bool,
powered: bool,
},
IronOre,
IronTrapdoor {
facing: HorizontalDirection,
half: Half,
open: bool,
powered: bool,
waterlogged: bool,
},
JackOLantern {
facing: HorizontalDirection,
},
Jigsaw {
facing: Direction,
},
Jukebox {
has_record: bool,
},
JungleButton {
face: AttachFace,
facing: HorizontalDirection,
powered: bool,
},
JungleDoor {
facing: HorizontalDirection,
half: DoubleBlockHalf,
hinge: DoorHingeSide,
open: bool,
powered: bool,
},
JungleFence {
east: bool,
north: bool,
south: bool,
waterlogged: bool,
west: bool,
},
JungleFenceGate {
facing: HorizontalDirection,
in_wall: bool,
open: bool,
powered: bool,
},
JungleLeaves {
distance: BoundedU8<1, 7>,
persistent: bool,
},
JungleLog {
axis: Axis,
},
JunglePlanks,
JunglePressurePlate {
powered: bool,
},
JungleSapling {
stage: BoundedU8<0, 1>,
},
JungleSign {
rotation: BoundedU8<0, 15>,
waterlogged: bool,
},
JungleSlab {
type: SlabType,
waterlogged: bool,
},
JungleStairs {
facing: HorizontalDirection,
half: Half,
shape: StairsShape,
waterlogged: bool,
},
JungleTrapdoor {
facing: HorizontalDirection,
half: Half,
open: bool,
powered: bool,
waterlogged: bool,
},
JungleWallSign {
facing: HorizontalDirection,
waterlogged: bool,
},
JungleWood {
axis: Axis,
},
Kelp {
age: BoundedU8<0, 25>,
},
KelpPlant,
Ladder {
facing: HorizontalDirection,
waterlogged: bool,
},
Lantern {
hanging: bool,
},
LapisBlock,
LapisOre,
LargeFern {
half: DoubleBlockHalf,
},
Lava {
level: BoundedU8<0, 15>,
},
Lectern {
facing: HorizontalDirection,
has_book: bool,
powered: bool,
},
Lever {
face: AttachFace,
facing: HorizontalDirection,
powered: bool,
},
LightBlueBanner {
rotation: BoundedU8<0, 15>,
},
LightBlueBed {
facing: HorizontalDirection,
occupied: bool,
part: BedPart,
},
LightBlueCarpet,
LightBlueConcrete,
LightBlueConcretePowder,
LightBlueGlazedTerracotta {
facing: HorizontalDirection,
},
LightBlueShulkerBox {
facing: Direction,
},
LightBlueStainedGlass,
LightBlueStainedGlassPane {
east: bool,
north: bool,
south: bool,
waterlogged: bool,
west: bool,
},
LightBlueTerracotta,
LightBlueWallBanner {
facing: HorizontalDirection,
},
LightBlueWool,
LightGrayBanner {
rotation: BoundedU8<0, 15>,
},
LightGrayBed {
facing: HorizontalDirection,
occupied: bool,
part: BedPart,
},
LightGrayCarpet,
LightGrayConcrete,
LightGrayConcretePowder,
LightGrayGlazedTerracotta {
facing: HorizontalDirection,
},
LightGrayShulkerBox {
facing: Direction,
},
LightGrayStainedGlass,
LightGrayStainedGlassPane {
east: bool,
north: bool,
south: bool,
waterlogged: bool,
west: bool,
},
LightGrayTerracotta,
LightGrayWallBanner {
facing: HorizontalDirection,
},
LightGrayWool,
LightWeightedPressurePlate {
power: BoundedU8<0, 15>,
},
Lilac {
half: DoubleBlockHalf,
},
LilyOfTheValley,
LilyPad,
LimeBanner {
rotation: BoundedU8<0, 15>,
},
LimeBed {
facing: HorizontalDirection,
occupied: bool,
part: BedPart,
},
LimeCarpet,
LimeConcrete,
LimeConcretePowder,
LimeGlazedTerracotta {
facing: HorizontalDirection,
},
LimeShulkerBox {
facing: Direction,
},
LimeStainedGlass,
LimeStainedGlassPane {
east: bool,
north: bool,
south: bool,
waterlogged: bool,
west: bool,
},
LimeTerracotta,
LimeWallBanner {
facing: HorizontalDirection,
},
LimeWool,
Loom {
facing: HorizontalDirection,
},
MagentaBanner {
rotation: BoundedU8<0, 15>,
},
MagentaBed {
facing: HorizontalDirection,
occupied: bool,
part: BedPart,
},
MagentaCarpet,
MagentaConcrete,
MagentaConcretePowder,
MagentaGlazedTerracotta {
facing: HorizontalDirection,
},
MagentaShulkerBox {
facing: Direction,
},
MagentaStainedGlass,
MagentaStainedGlassPane {
east: bool,
north: bool,
south: bool,
waterlogged: bool,
west: bool,
},
MagentaTerracotta,
MagentaWallBanner {
facing: HorizontalDirection,
},
MagentaWool,
MagmaBlock,
Melon,
MelonStem {
age: BoundedU8<0, 7>,
},
MossyCobblestone,
MossyCobblestoneSlab {
type: SlabType,
waterlogged: bool,
},
MossyCobblestoneStairs {
facing: HorizontalDirection,
half: Half,
shape: StairsShape,
waterlogged: bool,
},
MossyCobblestoneWall {
east: bool,
north: bool,
south: bool,
up: bool,
waterlogged: bool,
west: bool,
},
MossyStoneBrickSlab {
type: SlabType,
waterlogged: bool,
},
MossyStoneBrickStairs {
facing: HorizontalDirection,
half: Half,
shape: StairsShape,
waterlogged: bool,
},
MossyStoneBrickWall {
east: bool,
north: bool,
south: bool,
up: bool,
waterlogged: bool,
west: bool,
},
MossyStoneBricks,
MovingPiston {
facing: Direction,
type: PistonType,
},
MushroomStem {
down: bool,
east: bool,
north: bool,
south: bool,
up: bool,
west: bool,
},
Mycelium {
snowy: bool,
},
NetherBrickFence {
east: bool,
north: bool,
south: bool,
waterlogged: bool,
west: bool,
},
NetherBrickSlab {
type: SlabType,
waterlogged: bool,
},
NetherBrickStairs {
facing: HorizontalDirection,
half: Half,
shape: StairsShape,
waterlogged: bool,
},
NetherBrickWall {
east: bool,
north: bool,
south: bool,
up: bool,
waterlogged: bool,
west: bool,
},
NetherBricks,
NetherPortal {
axis: HorizontalAxis,
},
NetherQuartzOre,
NetherWart {
age: BoundedU8<0, 3>,
},
NetherWartBlock,
Netherrack,
NoteBlock {
instrument: NoteBlockInstrument,
note: BoundedU8<0, 24>,
powered: bool,
},
OakButton {
face: AttachFace,
facing: HorizontalDirection,
powered: bool,
},
OakDoor {
facing: HorizontalDirection,
half: DoubleBlockHalf,
hinge: DoorHingeSide,
open: bool,
powered: bool,
},
OakFence {
east: bool,
north: bool,
south: bool,
waterlogged: bool,
west: bool,
},
OakFenceGate {
facing: HorizontalDirection,
in_wall: bool,
open: bool,
powered: bool,
},
OakLeaves {
distance: BoundedU8<1, 7>,
persistent: bool,
},
OakLog {
axis: Axis,
},
OakPlanks,
OakPressurePlate {
powered: bool,
},
OakSapling {
stage: BoundedU8<0, 1>,
},
OakSign {
rotation: BoundedU8<0, 15>,
waterlogged: bool,
},
OakSlab {
type: SlabType,
waterlogged: bool,
},
OakStairs {
facing: HorizontalDirection,
half: Half,
shape: StairsShape,
waterlogged: bool,
},
OakTrapdoor {
facing: HorizontalDirection,
half: Half,
open: bool,
powered: bool,
waterlogged: bool,
},
OakWallSign {
facing: HorizontalDirection,
waterlogged: bool,
},
OakWood {
axis: Axis,
},
Observer {
facing: Direction,
powered: bool,
},
Obsidian,
OrangeBanner {
rotation: BoundedU8<0, 15>,
},
OrangeBed {
facing: HorizontalDirection,
occupied: bool,
part: BedPart,
},
OrangeCarpet,
OrangeConcrete,
OrangeConcretePowder,
OrangeGlazedTerracotta {
facing: HorizontalDirection,
},
OrangeShulkerBox {
facing: Direction,
},
OrangeStainedGlass,
OrangeStainedGlassPane {
east: bool,
north: bool,
south: bool,
waterlogged: bool,
west: bool,
},
OrangeTerracotta,
OrangeTulip,
OrangeWallBanner {
facing: HorizontalDirection,
},
OrangeWool,
OxeyeDaisy,
PackedIce,
Peony {
half: DoubleBlockHalf,
},
PetrifiedOakSlab {
type: SlabType,
waterlogged: bool,
},
PinkBanner {
rotation: BoundedU8<0, 15>,
},
PinkBed {
facing: HorizontalDirection,
occupied: bool,
part: BedPart,
},
PinkCarpet,
PinkConcrete,
PinkConcretePowder,
PinkGlazedTerracotta {
facing: HorizontalDirection,
},
PinkShulkerBox {
facing: Direction,
},
PinkStainedGlass,
PinkStainedGlassPane {
east: bool,
north: bool,
south: bool,
waterlogged: bool,
west: bool,
},
PinkTerracotta,
PinkTulip,
PinkWallBanner {
facing: HorizontalDirection,
},
PinkWool,
Piston {
extended: bool,
facing: Direction,
},
PistonHead {
facing: Direction,
short: bool,
type: PistonType,
},
PlayerHead {
rotation: BoundedU8<0, 15>,
},
PlayerWallHead {
facing: HorizontalDirection,
},
Podzol {
snowy: bool,
},
PolishedAndesite,
PolishedAndesiteSlab {
type: SlabType,
waterlogged: bool,
},
PolishedAndesiteStairs {
facing: HorizontalDirection,
half: Half,
shape: StairsShape,
waterlogged: bool,
},
PolishedDiorite,
PolishedDioriteSlab {
type: SlabType,
waterlogged: bool,
},
PolishedDioriteStairs {
facing: HorizontalDirection,
half: Half,
shape: StairsShape,
waterlogged: bool,
},
PolishedGranite,
PolishedGraniteSlab {
type: SlabType,
waterlogged: bool,
},
PolishedGraniteStairs {
facing: HorizontalDirection,
half: Half,
shape: StairsShape,
waterlogged: bool,
},
Poppy,
Potatoes {
age: BoundedU8<0, 7>,
},
PottedAcaciaSapling,
PottedAllium,
PottedAzureBluet,
PottedBamboo,
PottedBirchSapling,
PottedBlueOrchid,
PottedBrownMushroom,
PottedCactus,
PottedCornflower,
PottedDandelion,
PottedDarkOakSapling,
PottedDeadBush,
PottedFern,
PottedJungleSapling,
PottedLilyOfTheValley,
PottedOakSapling,
PottedOrangeTulip,
PottedOxeyeDaisy,
PottedPinkTulip,
PottedPoppy,
PottedRedMushroom,
PottedRedTulip,
PottedSpruceSapling,
PottedWhiteTulip,
PottedWitherRose,
PoweredRail {
powered: bool,
shape: StraightRailShape,
},
Prismarine,
PrismarineBrickSlab {
type: SlabType,
waterlogged: bool,
},
PrismarineBrickStairs {
facing: HorizontalDirection,
half: Half,
shape: StairsShape,
waterlogged: bool,
},
PrismarineBricks,
PrismarineSlab {
type: SlabType,
waterlogged: bool,
},
PrismarineStairs {
facing: HorizontalDirection,
half: Half,
shape: StairsShape,
waterlogged: bool,
},
PrismarineWall {
east: bool,
north: bool,
south: bool,
up: bool,
waterlogged: bool,
west: bool,
},
Pumpkin,
PumpkinStem {
age: BoundedU8<0, 7>,
},
PurpleBanner {
rotation: BoundedU8<0, 15>,
},
PurpleBed {
facing: HorizontalDirection,
occupied: bool,
part: BedPart,
},
PurpleCarpet,
PurpleConcrete,
PurpleConcretePowder,
PurpleGlazedTerracotta {
facing: HorizontalDirection,
},
PurpleShulkerBox {
facing: Direction,
},
PurpleStainedGlass,
PurpleStainedGlassPane {
east: bool,
north: bool,
south: bool,
waterlogged: bool,
west: bool,
},
PurpleTerracotta,
PurpleWallBanner {
facing: HorizontalDirection,
},
PurpleWool,
PurpurBlock,
PurpurPillar {
axis: Axis,
},
PurpurSlab {
type: SlabType,
waterlogged: bool,
},
PurpurStairs {
facing: HorizontalDirection,
half: Half,
shape: StairsShape,
waterlogged: bool,
},
QuartzBlock,
QuartzPillar {
axis: Axis,
},
QuartzSlab {
type: SlabType,
waterlogged: bool,
},
QuartzStairs {
facing: HorizontalDirection,
half: Half,
shape: StairsShape,
waterlogged: bool,
},
Rail {
shape: RailShape,
},
RedBanner {
rotation: BoundedU8<0, 15>,
},
RedBed {
facing: HorizontalDirection,
occupied: bool,
part: BedPart,
},
RedCarpet,
RedConcrete,
RedConcretePowder,
RedGlazedTerracotta {
facing: HorizontalDirection,
},
RedMushroom,
RedMushroomBlock {
down: bool,
east: bool,
north: bool,
south: bool,
up: bool,
west: bool,
},
RedNetherBrickSlab {
type: SlabType,
waterlogged: bool,
},
RedNetherBrickStairs {
facing: HorizontalDirection,
half: Half,
shape: StairsShape,
waterlogged: bool,
},
RedNetherBrickWall {
east: bool,
north: bool,
south: bool,
up: bool,
waterlogged: bool,
west: bool,
},
RedNetherBricks,
RedSand,
RedSandstone,
RedSandstoneSlab {
type: SlabType,
waterlogged: bool,
},
RedSandstoneStairs {
facing: HorizontalDirection,
half: Half,
shape: StairsShape,
waterlogged: bool,
},
RedSandstoneWall {
east: bool,
north: bool,
south: bool,
up: bool,
waterlogged: bool,
west: bool,
},
RedShulkerBox {
facing: Direction,
},
RedStainedGlass,
RedStainedGlassPane {
east: bool,
north: bool,
south: bool,
waterlogged: bool,
west: bool,
},
RedTerracotta,
RedTulip,
RedWallBanner {
facing: HorizontalDirection,
},
RedWool,
RedstoneBlock,
RedstoneLamp {
lit: bool,
},
RedstoneOre {
lit: bool,
},
RedstoneTorch {
lit: bool,
},
RedstoneWallTorch {
facing: HorizontalDirection,
lit: bool,
},
RedstoneWire {
east: RedstoneSide,
north: RedstoneSide,
power: BoundedU8<0, 15>,
south: RedstoneSide,
west: RedstoneSide,
},
Repeater {
delay: BoundedU8<1, 4>,
facing: HorizontalDirection,
locked: bool,
powered: bool,
},
RepeatingCommandBlock {
conditional: bool,
facing: Direction,
},
RoseBush {
half: DoubleBlockHalf,
},
Sand,
Sandstone,
SandstoneSlab {
type: SlabType,
waterlogged: bool,
},
SandstoneStairs {
facing: HorizontalDirection,
half: Half,
shape: StairsShape,
waterlogged: bool,
},
SandstoneWall {
east: bool,
north: bool,
south: bool,
up: bool,
waterlogged: bool,
west: bool,
},
Scaffolding {
bottom: bool,
distance: BoundedU8<0, 7>,
waterlogged: bool,
},
SeaLantern,
SeaPickle {
pickles: BoundedU8<1, 4>,
waterlogged: bool,
},
Seagrass,
ShulkerBox {
facing: Direction,
},
SkeletonSkull {
rotation: BoundedU8<0, 15>,
},
SkeletonWallSkull {
facing: HorizontalDirection,
},
SlimeBlock,
SmithingTable,
Smoker {
facing: HorizontalDirection,
lit: bool,
},
SmoothQuartz,
SmoothQuartzSlab {
type: SlabType,
waterlogged: bool,
},
SmoothQuartzStairs {
facing: HorizontalDirection,
half: Half,
shape: StairsShape,
waterlogged: bool,
},
SmoothRedSandstone,
SmoothRedSandstoneSlab {
type: SlabType,
waterlogged: bool,
},
SmoothRedSandstoneStairs {
facing: HorizontalDirection,
half: Half,
shape: StairsShape,
waterlogged: bool,
},
SmoothSandstone,
SmoothSandstoneSlab {
type: SlabType,
waterlogged: bool,
},
SmoothSandstoneStairs {
facing: HorizontalDirection,
half: Half,
shape: StairsShape,
waterlogged: bool,
},
SmoothStone,
SmoothStoneSlab {
type: SlabType,
waterlogged: bool,
},
Snow {
layers: BoundedU8<1, 8>,
},
SnowBlock,
SoulSand,
Spawner,
Sponge,
SpruceButton {
face: AttachFace,
facing: HorizontalDirection,
powered: bool,
},
SpruceDoor {
facing: HorizontalDirection,
half: DoubleBlockHalf,
hinge: DoorHingeSide,
open: bool,
powered: bool,
},
SpruceFence {
east: bool,
north: bool,
south: bool,
waterlogged: bool,
west: bool,
},
SpruceFenceGate {
facing: HorizontalDirection,
in_wall: bool,
open: bool,
powered: bool,
},
SpruceLeaves {
distance: BoundedU8<1, 7>,
persistent: bool,
},
SpruceLog {
axis: Axis,
},
SprucePlanks,
SprucePressurePlate {
powered: bool,
},
SpruceSapling {
stage: BoundedU8<0, 1>,
},
SpruceSign {
rotation: BoundedU8<0, 15>,
waterlogged: bool,
},
SpruceSlab {
type: SlabType,
waterlogged: bool,
},
SpruceStairs {
facing: HorizontalDirection,
half: Half,
shape: StairsShape,
waterlogged: bool,
},
SpruceTrapdoor {
facing: HorizontalDirection,
half: Half,
open: bool,
powered: bool,
waterlogged: bool,
},
SpruceWallSign {
facing: HorizontalDirection,
waterlogged: bool,
},
SpruceWood {
axis: Axis,
},
StickyPiston {
extended: bool,
facing: Direction,
},
Stone,
StoneBrickSlab {
type: SlabType,
waterlogged: bool,
},
StoneBrickStairs {
facing: HorizontalDirection,
half: Half,
shape: StairsShape,
waterlogged: bool,
},
StoneBrickWall {
east: bool,
north: bool,
south: bool,
up: bool,
waterlogged: bool,
west: bool,
},
StoneBricks,
StoneButton {
face: AttachFace,
facing: HorizontalDirection,
powered: bool,
},
StonePressurePlate {
powered: bool,
},
StoneSlab {
type: SlabType,
waterlogged: bool,
},
StoneStairs {
facing: HorizontalDirection,
half: Half,
shape: StairsShape,
waterlogged: bool,
},
Stonecutter {
facing: HorizontalDirection,
},
StrippedAcaciaLog {
axis: Axis,
},
StrippedAcaciaWood {
axis: Axis,
},
StrippedBirchLog {
axis: Axis,
},
StrippedBirchWood {
axis: Axis,
},
StrippedDarkOakLog {
axis: Axis,
},
StrippedDarkOakWood {
axis: Axis,
},
StrippedJungleLog {
axis: Axis,
},
StrippedJungleWood {
axis: Axis,
},
StrippedOakLog {
axis: Axis,
},
StrippedOakWood {
axis: Axis,
},
StrippedSpruceLog {
axis: Axis,
},
StrippedSpruceWood {
axis: Axis,
},
StructureBlock {
mode: StructureMode,
},
StructureVoid,
SugarCane {
age: BoundedU8<0, 15>,
},
Sunflower {
half: DoubleBlockHalf,
},
SweetBerryBush {
age: BoundedU8<0, 3>,
},
TallGrass {
half: DoubleBlockHalf,
},
TallSeagrass {
half: DoubleBlockHalf,
},
Terracotta,
Tnt {
unstable: bool,
},
Torch,
TrappedChest {
facing: HorizontalDirection,
type: ChestType,
waterlogged: bool,
},
Tripwire {
attached: bool,
disarmed: bool,
east: bool,
north: bool,
powered: bool,
south: bool,
west: bool,
},
TripwireHook {
attached: bool,
facing: HorizontalDirection,
powered: bool,
},
TubeCoral {
waterlogged: bool,
},
TubeCoralBlock,
TubeCoralFan {
waterlogged: bool,
},
TubeCoralWallFan {
facing: HorizontalDirection,
waterlogged: bool,
},
TurtleEgg {
eggs: BoundedU8<1, 4>,
hatch: BoundedU8<0, 2>,
},
Vine {
east: bool,
north: bool,
south: bool,
up: bool,
west: bool,
},
VoidAir,
WallTorch {
facing: HorizontalDirection,
},
Water {
level: BoundedU8<0, 15>,
},
WetSponge,
Wheat {
age: BoundedU8<0, 7>,
},
WhiteBanner {
rotation: BoundedU8<0, 15>,
},
WhiteBed {
facing: HorizontalDirection,
occupied: bool,
part: BedPart,
},
WhiteCarpet,
WhiteConcrete,
WhiteConcretePowder,
WhiteGlazedTerracotta {
facing: HorizontalDirection,
},
WhiteShulkerBox {
facing: Direction,
},
WhiteStainedGlass,
WhiteStainedGlassPane {
east: bool,
north: bool,
south: bool,
waterlogged: bool,
west: bool,
},
WhiteTerracotta,
WhiteTulip,
WhiteWallBanner {
facing: HorizontalDirection,
},
WhiteWool,
WitherRose,
WitherSkeletonSkull {
rotation: BoundedU8<0, 15>,
},
WitherSkeletonWallSkull {
facing: HorizontalDirection,
},
YellowBanner {
rotation: BoundedU8<0, 15>,
},
YellowBed {
facing: HorizontalDirection,
occupied: bool,
part: BedPart,
},
YellowCarpet,
YellowConcrete,
YellowConcretePowder,
YellowGlazedTerracotta {
facing: HorizontalDirection,
},
YellowShulkerBox {
facing: Direction,
},
YellowStainedGlass,
YellowStainedGlassPane {
east: bool,
north: bool,
south: bool,
waterlogged: bool,
west: bool,
},
YellowTerracotta,
YellowWallBanner {
facing: HorizontalDirection,
},
YellowWool,
ZombieHead {
rotation: BoundedU8<0, 15>,
},
ZombieWallHead {
facing: HorizontalDirection,
},
Other(GenericBlockState),
}1.15 and block-states only.Expand description
A typed block state for Minecraft 1.15.
Variants
AcaciaButton
minecraft:acacia_button
AcaciaDoor
minecraft:acacia_door
AcaciaFence
minecraft:acacia_fence
AcaciaFenceGate
minecraft:acacia_fence_gate
AcaciaLeaves
minecraft:acacia_leaves
AcaciaLog
minecraft:acacia_log
AcaciaPlanks
minecraft:acacia_planks
AcaciaPressurePlate
minecraft:acacia_pressure_plate
AcaciaSapling
minecraft:acacia_sapling
AcaciaSign
minecraft:acacia_sign
AcaciaSlab
minecraft:acacia_slab
AcaciaStairs
minecraft:acacia_stairs
AcaciaTrapdoor
minecraft:acacia_trapdoor
AcaciaWallSign
minecraft:acacia_wall_sign
AcaciaWood
minecraft:acacia_wood
ActivatorRail
minecraft:activator_rail
Air
minecraft:air
Allium
minecraft:allium
Andesite
minecraft:andesite
AndesiteSlab
minecraft:andesite_slab
AndesiteStairs
minecraft:andesite_stairs
AndesiteWall
minecraft:andesite_wall
Anvil
minecraft:anvil
Fields
facing: HorizontalDirectionAttachedMelonStem
minecraft:attached_melon_stem
Fields
facing: HorizontalDirectionAttachedPumpkinStem
minecraft:attached_pumpkin_stem
Fields
facing: HorizontalDirectionAzureBluet
minecraft:azure_bluet
Bamboo
minecraft:bamboo
BambooSapling
minecraft:bamboo_sapling
Barrel
minecraft:barrel
Barrier
minecraft:barrier
Beacon
minecraft:beacon
Bedrock
minecraft:bedrock
BeeNest
minecraft:bee_nest
Beehive
minecraft:beehive
Beetroots
minecraft:beetroots
Bell
minecraft:bell
BirchButton
minecraft:birch_button
BirchDoor
minecraft:birch_door
BirchFence
minecraft:birch_fence
BirchFenceGate
minecraft:birch_fence_gate
BirchLeaves
minecraft:birch_leaves
BirchLog
minecraft:birch_log
BirchPlanks
minecraft:birch_planks
BirchPressurePlate
minecraft:birch_pressure_plate
BirchSapling
minecraft:birch_sapling
BirchSign
minecraft:birch_sign
BirchSlab
minecraft:birch_slab
BirchStairs
minecraft:birch_stairs
BirchTrapdoor
minecraft:birch_trapdoor
BirchWallSign
minecraft:birch_wall_sign
BirchWood
minecraft:birch_wood
BlackBanner
minecraft:black_banner
BlackBed
minecraft:black_bed
BlackCarpet
minecraft:black_carpet
BlackConcrete
minecraft:black_concrete
BlackConcretePowder
minecraft:black_concrete_powder
BlackGlazedTerracotta
minecraft:black_glazed_terracotta
Fields
facing: HorizontalDirectionBlackShulkerBox
minecraft:black_shulker_box
BlackStainedGlass
minecraft:black_stained_glass
BlackStainedGlassPane
minecraft:black_stained_glass_pane
BlackTerracotta
minecraft:black_terracotta
BlackWallBanner
minecraft:black_wall_banner
Fields
facing: HorizontalDirectionBlackWool
minecraft:black_wool
BlastFurnace
minecraft:blast_furnace
BlueBanner
minecraft:blue_banner
BlueBed
minecraft:blue_bed
BlueCarpet
minecraft:blue_carpet
BlueConcrete
minecraft:blue_concrete
BlueConcretePowder
minecraft:blue_concrete_powder
BlueGlazedTerracotta
minecraft:blue_glazed_terracotta
Fields
facing: HorizontalDirectionBlueIce
minecraft:blue_ice
BlueOrchid
minecraft:blue_orchid
BlueShulkerBox
minecraft:blue_shulker_box
BlueStainedGlass
minecraft:blue_stained_glass
BlueStainedGlassPane
minecraft:blue_stained_glass_pane
BlueTerracotta
minecraft:blue_terracotta
BlueWallBanner
minecraft:blue_wall_banner
Fields
facing: HorizontalDirectionBlueWool
minecraft:blue_wool
BoneBlock
minecraft:bone_block
Bookshelf
minecraft:bookshelf
BrainCoral
minecraft:brain_coral
BrainCoralBlock
minecraft:brain_coral_block
BrainCoralFan
minecraft:brain_coral_fan
BrainCoralWallFan
minecraft:brain_coral_wall_fan
BrewingStand
minecraft:brewing_stand
BrickSlab
minecraft:brick_slab
BrickStairs
minecraft:brick_stairs
BrickWall
minecraft:brick_wall
Bricks
minecraft:bricks
BrownBanner
minecraft:brown_banner
BrownBed
minecraft:brown_bed
BrownCarpet
minecraft:brown_carpet
BrownConcrete
minecraft:brown_concrete
BrownConcretePowder
minecraft:brown_concrete_powder
BrownGlazedTerracotta
minecraft:brown_glazed_terracotta
Fields
facing: HorizontalDirectionBrownMushroom
minecraft:brown_mushroom
BrownMushroomBlock
minecraft:brown_mushroom_block
BrownShulkerBox
minecraft:brown_shulker_box
BrownStainedGlass
minecraft:brown_stained_glass
BrownStainedGlassPane
minecraft:brown_stained_glass_pane
BrownTerracotta
minecraft:brown_terracotta
BrownWallBanner
minecraft:brown_wall_banner
Fields
facing: HorizontalDirectionBrownWool
minecraft:brown_wool
BubbleColumn
minecraft:bubble_column
BubbleCoral
minecraft:bubble_coral
BubbleCoralBlock
minecraft:bubble_coral_block
BubbleCoralFan
minecraft:bubble_coral_fan
BubbleCoralWallFan
minecraft:bubble_coral_wall_fan
Cactus
minecraft:cactus
Cake
minecraft:cake
Campfire
minecraft:campfire
Carrots
minecraft:carrots
CartographyTable
minecraft:cartography_table
CarvedPumpkin
minecraft:carved_pumpkin
Fields
facing: HorizontalDirectionCauldron
minecraft:cauldron
CaveAir
minecraft:cave_air
ChainCommandBlock
minecraft:chain_command_block
Chest
minecraft:chest
ChippedAnvil
minecraft:chipped_anvil
Fields
facing: HorizontalDirectionChiseledQuartzBlock
minecraft:chiseled_quartz_block
ChiseledRedSandstone
minecraft:chiseled_red_sandstone
ChiseledSandstone
minecraft:chiseled_sandstone
ChiseledStoneBricks
minecraft:chiseled_stone_bricks
ChorusFlower
minecraft:chorus_flower
ChorusPlant
minecraft:chorus_plant
Clay
minecraft:clay
CoalBlock
minecraft:coal_block
CoalOre
minecraft:coal_ore
CoarseDirt
minecraft:coarse_dirt
Cobblestone
minecraft:cobblestone
CobblestoneSlab
minecraft:cobblestone_slab
CobblestoneStairs
minecraft:cobblestone_stairs
CobblestoneWall
minecraft:cobblestone_wall
Cobweb
minecraft:cobweb
Cocoa
minecraft:cocoa
CommandBlock
minecraft:command_block
Comparator
minecraft:comparator
Composter
minecraft:composter
Conduit
minecraft:conduit
Cornflower
minecraft:cornflower
CrackedStoneBricks
minecraft:cracked_stone_bricks
CraftingTable
minecraft:crafting_table
CreeperHead
minecraft:creeper_head
CreeperWallHead
minecraft:creeper_wall_head
Fields
facing: HorizontalDirectionCutRedSandstone
minecraft:cut_red_sandstone
CutRedSandstoneSlab
minecraft:cut_red_sandstone_slab
CutSandstone
minecraft:cut_sandstone
CutSandstoneSlab
minecraft:cut_sandstone_slab
CyanBanner
minecraft:cyan_banner
CyanBed
minecraft:cyan_bed
CyanCarpet
minecraft:cyan_carpet
CyanConcrete
minecraft:cyan_concrete
CyanConcretePowder
minecraft:cyan_concrete_powder
CyanGlazedTerracotta
minecraft:cyan_glazed_terracotta
Fields
facing: HorizontalDirectionCyanShulkerBox
minecraft:cyan_shulker_box
CyanStainedGlass
minecraft:cyan_stained_glass
CyanStainedGlassPane
minecraft:cyan_stained_glass_pane
CyanTerracotta
minecraft:cyan_terracotta
CyanWallBanner
minecraft:cyan_wall_banner
Fields
facing: HorizontalDirectionCyanWool
minecraft:cyan_wool
DamagedAnvil
minecraft:damaged_anvil
Fields
facing: HorizontalDirectionDandelion
minecraft:dandelion
DarkOakButton
minecraft:dark_oak_button
DarkOakDoor
minecraft:dark_oak_door
DarkOakFence
minecraft:dark_oak_fence
DarkOakFenceGate
minecraft:dark_oak_fence_gate
DarkOakLeaves
minecraft:dark_oak_leaves
DarkOakLog
minecraft:dark_oak_log
DarkOakPlanks
minecraft:dark_oak_planks
DarkOakPressurePlate
minecraft:dark_oak_pressure_plate
DarkOakSapling
minecraft:dark_oak_sapling
DarkOakSign
minecraft:dark_oak_sign
DarkOakSlab
minecraft:dark_oak_slab
DarkOakStairs
minecraft:dark_oak_stairs
DarkOakTrapdoor
minecraft:dark_oak_trapdoor
DarkOakWallSign
minecraft:dark_oak_wall_sign
DarkOakWood
minecraft:dark_oak_wood
DarkPrismarine
minecraft:dark_prismarine
DarkPrismarineSlab
minecraft:dark_prismarine_slab
DarkPrismarineStairs
minecraft:dark_prismarine_stairs
DaylightDetector
minecraft:daylight_detector
DeadBrainCoral
minecraft:dead_brain_coral
DeadBrainCoralBlock
minecraft:dead_brain_coral_block
DeadBrainCoralFan
minecraft:dead_brain_coral_fan
DeadBrainCoralWallFan
minecraft:dead_brain_coral_wall_fan
DeadBubbleCoral
minecraft:dead_bubble_coral
DeadBubbleCoralBlock
minecraft:dead_bubble_coral_block
DeadBubbleCoralFan
minecraft:dead_bubble_coral_fan
DeadBubbleCoralWallFan
minecraft:dead_bubble_coral_wall_fan
DeadBush
minecraft:dead_bush
DeadFireCoral
minecraft:dead_fire_coral
DeadFireCoralBlock
minecraft:dead_fire_coral_block
DeadFireCoralFan
minecraft:dead_fire_coral_fan
DeadFireCoralWallFan
minecraft:dead_fire_coral_wall_fan
DeadHornCoral
minecraft:dead_horn_coral
DeadHornCoralBlock
minecraft:dead_horn_coral_block
DeadHornCoralFan
minecraft:dead_horn_coral_fan
DeadHornCoralWallFan
minecraft:dead_horn_coral_wall_fan
DeadTubeCoral
minecraft:dead_tube_coral
DeadTubeCoralBlock
minecraft:dead_tube_coral_block
DeadTubeCoralFan
minecraft:dead_tube_coral_fan
DeadTubeCoralWallFan
minecraft:dead_tube_coral_wall_fan
DetectorRail
minecraft:detector_rail
DiamondBlock
minecraft:diamond_block
DiamondOre
minecraft:diamond_ore
Diorite
minecraft:diorite
DioriteSlab
minecraft:diorite_slab
DioriteStairs
minecraft:diorite_stairs
DioriteWall
minecraft:diorite_wall
Dirt
minecraft:dirt
Dispenser
minecraft:dispenser
DragonEgg
minecraft:dragon_egg
DragonHead
minecraft:dragon_head
DragonWallHead
minecraft:dragon_wall_head
Fields
facing: HorizontalDirectionDriedKelpBlock
minecraft:dried_kelp_block
Dropper
minecraft:dropper
EmeraldBlock
minecraft:emerald_block
EmeraldOre
minecraft:emerald_ore
EnchantingTable
minecraft:enchanting_table
EndGateway
minecraft:end_gateway
EndPortal
minecraft:end_portal
EndPortalFrame
minecraft:end_portal_frame
EndRod
minecraft:end_rod
EndStone
minecraft:end_stone
EndStoneBrickSlab
minecraft:end_stone_brick_slab
EndStoneBrickStairs
minecraft:end_stone_brick_stairs
EndStoneBrickWall
minecraft:end_stone_brick_wall
EndStoneBricks
minecraft:end_stone_bricks
EnderChest
minecraft:ender_chest
Farmland
minecraft:farmland
Fern
minecraft:fern
Fire
minecraft:fire
FireCoral
minecraft:fire_coral
FireCoralBlock
minecraft:fire_coral_block
FireCoralFan
minecraft:fire_coral_fan
FireCoralWallFan
minecraft:fire_coral_wall_fan
FletchingTable
minecraft:fletching_table
FlowerPot
minecraft:flower_pot
FrostedIce
minecraft:frosted_ice
Furnace
minecraft:furnace
Glass
minecraft:glass
GlassPane
minecraft:glass_pane
Glowstone
minecraft:glowstone
GoldBlock
minecraft:gold_block
GoldOre
minecraft:gold_ore
Granite
minecraft:granite
GraniteSlab
minecraft:granite_slab
GraniteStairs
minecraft:granite_stairs
GraniteWall
minecraft:granite_wall
Grass
minecraft:grass
GrassBlock
minecraft:grass_block
GrassPath
minecraft:grass_path
Gravel
minecraft:gravel
GrayBanner
minecraft:gray_banner
GrayBed
minecraft:gray_bed
GrayCarpet
minecraft:gray_carpet
GrayConcrete
minecraft:gray_concrete
GrayConcretePowder
minecraft:gray_concrete_powder
GrayGlazedTerracotta
minecraft:gray_glazed_terracotta
Fields
facing: HorizontalDirectionGrayShulkerBox
minecraft:gray_shulker_box
GrayStainedGlass
minecraft:gray_stained_glass
GrayStainedGlassPane
minecraft:gray_stained_glass_pane
GrayTerracotta
minecraft:gray_terracotta
GrayWallBanner
minecraft:gray_wall_banner
Fields
facing: HorizontalDirectionGrayWool
minecraft:gray_wool
GreenBanner
minecraft:green_banner
GreenBed
minecraft:green_bed
GreenCarpet
minecraft:green_carpet
GreenConcrete
minecraft:green_concrete
GreenConcretePowder
minecraft:green_concrete_powder
GreenGlazedTerracotta
minecraft:green_glazed_terracotta
Fields
facing: HorizontalDirectionGreenShulkerBox
minecraft:green_shulker_box
GreenStainedGlass
minecraft:green_stained_glass
GreenStainedGlassPane
minecraft:green_stained_glass_pane
GreenTerracotta
minecraft:green_terracotta
GreenWallBanner
minecraft:green_wall_banner
Fields
facing: HorizontalDirectionGreenWool
minecraft:green_wool
Grindstone
minecraft:grindstone
HayBlock
minecraft:hay_block
HeavyWeightedPressurePlate
minecraft:heavy_weighted_pressure_plate
HoneyBlock
minecraft:honey_block
HoneycombBlock
minecraft:honeycomb_block
Hopper
minecraft:hopper
HornCoral
minecraft:horn_coral
HornCoralBlock
minecraft:horn_coral_block
HornCoralFan
minecraft:horn_coral_fan
HornCoralWallFan
minecraft:horn_coral_wall_fan
Ice
minecraft:ice
InfestedChiseledStoneBricks
minecraft:infested_chiseled_stone_bricks
InfestedCobblestone
minecraft:infested_cobblestone
InfestedCrackedStoneBricks
minecraft:infested_cracked_stone_bricks
InfestedMossyStoneBricks
minecraft:infested_mossy_stone_bricks
InfestedStone
minecraft:infested_stone
InfestedStoneBricks
minecraft:infested_stone_bricks
IronBars
minecraft:iron_bars
IronBlock
minecraft:iron_block
IronDoor
minecraft:iron_door
IronOre
minecraft:iron_ore
IronTrapdoor
minecraft:iron_trapdoor
JackOLantern
minecraft:jack_o_lantern
Fields
facing: HorizontalDirectionJigsaw
minecraft:jigsaw
Jukebox
minecraft:jukebox
JungleButton
minecraft:jungle_button
JungleDoor
minecraft:jungle_door
JungleFence
minecraft:jungle_fence
JungleFenceGate
minecraft:jungle_fence_gate
JungleLeaves
minecraft:jungle_leaves
JungleLog
minecraft:jungle_log
JunglePlanks
minecraft:jungle_planks
JunglePressurePlate
minecraft:jungle_pressure_plate
JungleSapling
minecraft:jungle_sapling
JungleSign
minecraft:jungle_sign
JungleSlab
minecraft:jungle_slab
JungleStairs
minecraft:jungle_stairs
JungleTrapdoor
minecraft:jungle_trapdoor
JungleWallSign
minecraft:jungle_wall_sign
JungleWood
minecraft:jungle_wood
Kelp
minecraft:kelp
KelpPlant
minecraft:kelp_plant
Ladder
minecraft:ladder
Lantern
minecraft:lantern
LapisBlock
minecraft:lapis_block
LapisOre
minecraft:lapis_ore
LargeFern
minecraft:large_fern
Fields
half: DoubleBlockHalfLava
minecraft:lava
Lectern
minecraft:lectern
Lever
minecraft:lever
LightBlueBanner
minecraft:light_blue_banner
LightBlueBed
minecraft:light_blue_bed
LightBlueCarpet
minecraft:light_blue_carpet
LightBlueConcrete
minecraft:light_blue_concrete
LightBlueConcretePowder
minecraft:light_blue_concrete_powder
LightBlueGlazedTerracotta
minecraft:light_blue_glazed_terracotta
Fields
facing: HorizontalDirectionLightBlueShulkerBox
minecraft:light_blue_shulker_box
LightBlueStainedGlass
minecraft:light_blue_stained_glass
LightBlueStainedGlassPane
minecraft:light_blue_stained_glass_pane
LightBlueTerracotta
minecraft:light_blue_terracotta
LightBlueWallBanner
minecraft:light_blue_wall_banner
Fields
facing: HorizontalDirectionLightBlueWool
minecraft:light_blue_wool
LightGrayBanner
minecraft:light_gray_banner
LightGrayBed
minecraft:light_gray_bed
LightGrayCarpet
minecraft:light_gray_carpet
LightGrayConcrete
minecraft:light_gray_concrete
LightGrayConcretePowder
minecraft:light_gray_concrete_powder
LightGrayGlazedTerracotta
minecraft:light_gray_glazed_terracotta
Fields
facing: HorizontalDirectionLightGrayShulkerBox
minecraft:light_gray_shulker_box
LightGrayStainedGlass
minecraft:light_gray_stained_glass
LightGrayStainedGlassPane
minecraft:light_gray_stained_glass_pane
LightGrayTerracotta
minecraft:light_gray_terracotta
LightGrayWallBanner
minecraft:light_gray_wall_banner
Fields
facing: HorizontalDirectionLightGrayWool
minecraft:light_gray_wool
LightWeightedPressurePlate
minecraft:light_weighted_pressure_plate
Lilac
minecraft:lilac
Fields
half: DoubleBlockHalfLilyOfTheValley
minecraft:lily_of_the_valley
LilyPad
minecraft:lily_pad
LimeBanner
minecraft:lime_banner
LimeBed
minecraft:lime_bed
LimeCarpet
minecraft:lime_carpet
LimeConcrete
minecraft:lime_concrete
LimeConcretePowder
minecraft:lime_concrete_powder
LimeGlazedTerracotta
minecraft:lime_glazed_terracotta
Fields
facing: HorizontalDirectionLimeShulkerBox
minecraft:lime_shulker_box
LimeStainedGlass
minecraft:lime_stained_glass
LimeStainedGlassPane
minecraft:lime_stained_glass_pane
LimeTerracotta
minecraft:lime_terracotta
LimeWallBanner
minecraft:lime_wall_banner
Fields
facing: HorizontalDirectionLimeWool
minecraft:lime_wool
Loom
minecraft:loom
Fields
facing: HorizontalDirectionMagentaBanner
minecraft:magenta_banner
MagentaBed
minecraft:magenta_bed
MagentaCarpet
minecraft:magenta_carpet
MagentaConcrete
minecraft:magenta_concrete
MagentaConcretePowder
minecraft:magenta_concrete_powder
MagentaGlazedTerracotta
minecraft:magenta_glazed_terracotta
Fields
facing: HorizontalDirectionMagentaShulkerBox
minecraft:magenta_shulker_box
MagentaStainedGlass
minecraft:magenta_stained_glass
MagentaStainedGlassPane
minecraft:magenta_stained_glass_pane
MagentaTerracotta
minecraft:magenta_terracotta
MagentaWallBanner
minecraft:magenta_wall_banner
Fields
facing: HorizontalDirectionMagentaWool
minecraft:magenta_wool
MagmaBlock
minecraft:magma_block
Melon
minecraft:melon
MelonStem
minecraft:melon_stem
MossyCobblestone
minecraft:mossy_cobblestone
MossyCobblestoneSlab
minecraft:mossy_cobblestone_slab
MossyCobblestoneStairs
minecraft:mossy_cobblestone_stairs
MossyCobblestoneWall
minecraft:mossy_cobblestone_wall
MossyStoneBrickSlab
minecraft:mossy_stone_brick_slab
MossyStoneBrickStairs
minecraft:mossy_stone_brick_stairs
MossyStoneBrickWall
minecraft:mossy_stone_brick_wall
MossyStoneBricks
minecraft:mossy_stone_bricks
MovingPiston
minecraft:moving_piston
MushroomStem
minecraft:mushroom_stem
Mycelium
minecraft:mycelium
NetherBrickFence
minecraft:nether_brick_fence
NetherBrickSlab
minecraft:nether_brick_slab
NetherBrickStairs
minecraft:nether_brick_stairs
NetherBrickWall
minecraft:nether_brick_wall
NetherBricks
minecraft:nether_bricks
NetherPortal
minecraft:nether_portal
Fields
axis: HorizontalAxisNetherQuartzOre
minecraft:nether_quartz_ore
NetherWart
minecraft:nether_wart
NetherWartBlock
minecraft:nether_wart_block
Netherrack
minecraft:netherrack
NoteBlock
minecraft:note_block
OakButton
minecraft:oak_button
OakDoor
minecraft:oak_door
OakFence
minecraft:oak_fence
OakFenceGate
minecraft:oak_fence_gate
OakLeaves
minecraft:oak_leaves
OakLog
minecraft:oak_log
OakPlanks
minecraft:oak_planks
OakPressurePlate
minecraft:oak_pressure_plate
OakSapling
minecraft:oak_sapling
OakSign
minecraft:oak_sign
OakSlab
minecraft:oak_slab
OakStairs
minecraft:oak_stairs
OakTrapdoor
minecraft:oak_trapdoor
OakWallSign
minecraft:oak_wall_sign
OakWood
minecraft:oak_wood
Observer
minecraft:observer
Obsidian
minecraft:obsidian
OrangeBanner
minecraft:orange_banner
OrangeBed
minecraft:orange_bed
OrangeCarpet
minecraft:orange_carpet
OrangeConcrete
minecraft:orange_concrete
OrangeConcretePowder
minecraft:orange_concrete_powder
OrangeGlazedTerracotta
minecraft:orange_glazed_terracotta
Fields
facing: HorizontalDirectionOrangeShulkerBox
minecraft:orange_shulker_box
OrangeStainedGlass
minecraft:orange_stained_glass
OrangeStainedGlassPane
minecraft:orange_stained_glass_pane
OrangeTerracotta
minecraft:orange_terracotta
OrangeTulip
minecraft:orange_tulip
OrangeWallBanner
minecraft:orange_wall_banner
Fields
facing: HorizontalDirectionOrangeWool
minecraft:orange_wool
OxeyeDaisy
minecraft:oxeye_daisy
PackedIce
minecraft:packed_ice
Peony
minecraft:peony
Fields
half: DoubleBlockHalfPetrifiedOakSlab
minecraft:petrified_oak_slab
PinkBanner
minecraft:pink_banner
PinkBed
minecraft:pink_bed
PinkCarpet
minecraft:pink_carpet
PinkConcrete
minecraft:pink_concrete
PinkConcretePowder
minecraft:pink_concrete_powder
PinkGlazedTerracotta
minecraft:pink_glazed_terracotta
Fields
facing: HorizontalDirectionPinkShulkerBox
minecraft:pink_shulker_box
PinkStainedGlass
minecraft:pink_stained_glass
PinkStainedGlassPane
minecraft:pink_stained_glass_pane
PinkTerracotta
minecraft:pink_terracotta
PinkTulip
minecraft:pink_tulip
PinkWallBanner
minecraft:pink_wall_banner
Fields
facing: HorizontalDirectionPinkWool
minecraft:pink_wool
Piston
minecraft:piston
PistonHead
minecraft:piston_head
PlayerHead
minecraft:player_head
PlayerWallHead
minecraft:player_wall_head
Fields
facing: HorizontalDirectionPodzol
minecraft:podzol
PolishedAndesite
minecraft:polished_andesite
PolishedAndesiteSlab
minecraft:polished_andesite_slab
PolishedAndesiteStairs
minecraft:polished_andesite_stairs
PolishedDiorite
minecraft:polished_diorite
PolishedDioriteSlab
minecraft:polished_diorite_slab
PolishedDioriteStairs
minecraft:polished_diorite_stairs
PolishedGranite
minecraft:polished_granite
PolishedGraniteSlab
minecraft:polished_granite_slab
PolishedGraniteStairs
minecraft:polished_granite_stairs
Poppy
minecraft:poppy
Potatoes
minecraft:potatoes
PottedAcaciaSapling
minecraft:potted_acacia_sapling
PottedAllium
minecraft:potted_allium
PottedAzureBluet
minecraft:potted_azure_bluet
PottedBamboo
minecraft:potted_bamboo
PottedBirchSapling
minecraft:potted_birch_sapling
PottedBlueOrchid
minecraft:potted_blue_orchid
PottedBrownMushroom
minecraft:potted_brown_mushroom
PottedCactus
minecraft:potted_cactus
PottedCornflower
minecraft:potted_cornflower
PottedDandelion
minecraft:potted_dandelion
PottedDarkOakSapling
minecraft:potted_dark_oak_sapling
PottedDeadBush
minecraft:potted_dead_bush
PottedFern
minecraft:potted_fern
PottedJungleSapling
minecraft:potted_jungle_sapling
PottedLilyOfTheValley
minecraft:potted_lily_of_the_valley
PottedOakSapling
minecraft:potted_oak_sapling
PottedOrangeTulip
minecraft:potted_orange_tulip
PottedOxeyeDaisy
minecraft:potted_oxeye_daisy
PottedPinkTulip
minecraft:potted_pink_tulip
PottedPoppy
minecraft:potted_poppy
PottedRedMushroom
minecraft:potted_red_mushroom
PottedRedTulip
minecraft:potted_red_tulip
PottedSpruceSapling
minecraft:potted_spruce_sapling
PottedWhiteTulip
minecraft:potted_white_tulip
PottedWitherRose
minecraft:potted_wither_rose
PoweredRail
minecraft:powered_rail
Prismarine
minecraft:prismarine
PrismarineBrickSlab
minecraft:prismarine_brick_slab
PrismarineBrickStairs
minecraft:prismarine_brick_stairs
PrismarineBricks
minecraft:prismarine_bricks
PrismarineSlab
minecraft:prismarine_slab
PrismarineStairs
minecraft:prismarine_stairs
PrismarineWall
minecraft:prismarine_wall
Pumpkin
minecraft:pumpkin
PumpkinStem
minecraft:pumpkin_stem
PurpleBanner
minecraft:purple_banner
PurpleBed
minecraft:purple_bed
PurpleCarpet
minecraft:purple_carpet
PurpleConcrete
minecraft:purple_concrete
PurpleConcretePowder
minecraft:purple_concrete_powder
PurpleGlazedTerracotta
minecraft:purple_glazed_terracotta
Fields
facing: HorizontalDirectionPurpleShulkerBox
minecraft:purple_shulker_box
PurpleStainedGlass
minecraft:purple_stained_glass
PurpleStainedGlassPane
minecraft:purple_stained_glass_pane
PurpleTerracotta
minecraft:purple_terracotta
PurpleWallBanner
minecraft:purple_wall_banner
Fields
facing: HorizontalDirectionPurpleWool
minecraft:purple_wool
PurpurBlock
minecraft:purpur_block
PurpurPillar
minecraft:purpur_pillar
PurpurSlab
minecraft:purpur_slab
PurpurStairs
minecraft:purpur_stairs
QuartzBlock
minecraft:quartz_block
QuartzPillar
minecraft:quartz_pillar
QuartzSlab
minecraft:quartz_slab
QuartzStairs
minecraft:quartz_stairs
Rail
minecraft:rail
RedBanner
minecraft:red_banner
RedBed
minecraft:red_bed
RedCarpet
minecraft:red_carpet
RedConcrete
minecraft:red_concrete
RedConcretePowder
minecraft:red_concrete_powder
RedGlazedTerracotta
minecraft:red_glazed_terracotta
Fields
facing: HorizontalDirectionRedMushroom
minecraft:red_mushroom
RedMushroomBlock
minecraft:red_mushroom_block
RedNetherBrickSlab
minecraft:red_nether_brick_slab
RedNetherBrickStairs
minecraft:red_nether_brick_stairs
RedNetherBrickWall
minecraft:red_nether_brick_wall
RedNetherBricks
minecraft:red_nether_bricks
RedSand
minecraft:red_sand
RedSandstone
minecraft:red_sandstone
RedSandstoneSlab
minecraft:red_sandstone_slab
RedSandstoneStairs
minecraft:red_sandstone_stairs
RedSandstoneWall
minecraft:red_sandstone_wall
RedShulkerBox
minecraft:red_shulker_box
RedStainedGlass
minecraft:red_stained_glass
RedStainedGlassPane
minecraft:red_stained_glass_pane
RedTerracotta
minecraft:red_terracotta
RedTulip
minecraft:red_tulip
RedWallBanner
minecraft:red_wall_banner
Fields
facing: HorizontalDirectionRedWool
minecraft:red_wool
RedstoneBlock
minecraft:redstone_block
RedstoneLamp
minecraft:redstone_lamp
RedstoneOre
minecraft:redstone_ore
RedstoneTorch
minecraft:redstone_torch
RedstoneWallTorch
minecraft:redstone_wall_torch
RedstoneWire
minecraft:redstone_wire
Repeater
minecraft:repeater
RepeatingCommandBlock
minecraft:repeating_command_block
RoseBush
minecraft:rose_bush
Fields
half: DoubleBlockHalfSand
minecraft:sand
Sandstone
minecraft:sandstone
SandstoneSlab
minecraft:sandstone_slab
SandstoneStairs
minecraft:sandstone_stairs
SandstoneWall
minecraft:sandstone_wall
Scaffolding
minecraft:scaffolding
SeaLantern
minecraft:sea_lantern
SeaPickle
minecraft:sea_pickle
Seagrass
minecraft:seagrass
ShulkerBox
minecraft:shulker_box
SkeletonSkull
minecraft:skeleton_skull
SkeletonWallSkull
minecraft:skeleton_wall_skull
Fields
facing: HorizontalDirectionSlimeBlock
minecraft:slime_block
SmithingTable
minecraft:smithing_table
Smoker
minecraft:smoker
SmoothQuartz
minecraft:smooth_quartz
SmoothQuartzSlab
minecraft:smooth_quartz_slab
SmoothQuartzStairs
minecraft:smooth_quartz_stairs
SmoothRedSandstone
minecraft:smooth_red_sandstone
SmoothRedSandstoneSlab
minecraft:smooth_red_sandstone_slab
SmoothRedSandstoneStairs
minecraft:smooth_red_sandstone_stairs
SmoothSandstone
minecraft:smooth_sandstone
SmoothSandstoneSlab
minecraft:smooth_sandstone_slab
SmoothSandstoneStairs
minecraft:smooth_sandstone_stairs
SmoothStone
minecraft:smooth_stone
SmoothStoneSlab
minecraft:smooth_stone_slab
Snow
minecraft:snow
SnowBlock
minecraft:snow_block
SoulSand
minecraft:soul_sand
Spawner
minecraft:spawner
Sponge
minecraft:sponge
SpruceButton
minecraft:spruce_button
SpruceDoor
minecraft:spruce_door
SpruceFence
minecraft:spruce_fence
SpruceFenceGate
minecraft:spruce_fence_gate
SpruceLeaves
minecraft:spruce_leaves
SpruceLog
minecraft:spruce_log
SprucePlanks
minecraft:spruce_planks
SprucePressurePlate
minecraft:spruce_pressure_plate
SpruceSapling
minecraft:spruce_sapling
SpruceSign
minecraft:spruce_sign
SpruceSlab
minecraft:spruce_slab
SpruceStairs
minecraft:spruce_stairs
SpruceTrapdoor
minecraft:spruce_trapdoor
SpruceWallSign
minecraft:spruce_wall_sign
SpruceWood
minecraft:spruce_wood
StickyPiston
minecraft:sticky_piston
Stone
minecraft:stone
StoneBrickSlab
minecraft:stone_brick_slab
StoneBrickStairs
minecraft:stone_brick_stairs
StoneBrickWall
minecraft:stone_brick_wall
StoneBricks
minecraft:stone_bricks
StoneButton
minecraft:stone_button
StonePressurePlate
minecraft:stone_pressure_plate
StoneSlab
minecraft:stone_slab
StoneStairs
minecraft:stone_stairs
Stonecutter
minecraft:stonecutter
Fields
facing: HorizontalDirectionStrippedAcaciaLog
minecraft:stripped_acacia_log
StrippedAcaciaWood
minecraft:stripped_acacia_wood
StrippedBirchLog
minecraft:stripped_birch_log
StrippedBirchWood
minecraft:stripped_birch_wood
StrippedDarkOakLog
minecraft:stripped_dark_oak_log
StrippedDarkOakWood
minecraft:stripped_dark_oak_wood
StrippedJungleLog
minecraft:stripped_jungle_log
StrippedJungleWood
minecraft:stripped_jungle_wood
StrippedOakLog
minecraft:stripped_oak_log
StrippedOakWood
minecraft:stripped_oak_wood
StrippedSpruceLog
minecraft:stripped_spruce_log
StrippedSpruceWood
minecraft:stripped_spruce_wood
StructureBlock
minecraft:structure_block
Fields
mode: StructureModeStructureVoid
minecraft:structure_void
SugarCane
minecraft:sugar_cane
Sunflower
minecraft:sunflower
Fields
half: DoubleBlockHalfSweetBerryBush
minecraft:sweet_berry_bush
TallGrass
minecraft:tall_grass
Fields
half: DoubleBlockHalfTallSeagrass
minecraft:tall_seagrass
Fields
half: DoubleBlockHalfTerracotta
minecraft:terracotta
Tnt
minecraft:tnt
Torch
minecraft:torch
TrappedChest
minecraft:trapped_chest
Tripwire
minecraft:tripwire
TripwireHook
minecraft:tripwire_hook
TubeCoral
minecraft:tube_coral
TubeCoralBlock
minecraft:tube_coral_block
TubeCoralFan
minecraft:tube_coral_fan
TubeCoralWallFan
minecraft:tube_coral_wall_fan
TurtleEgg
minecraft:turtle_egg
Vine
minecraft:vine
VoidAir
minecraft:void_air
WallTorch
minecraft:wall_torch
Fields
facing: HorizontalDirectionWater
minecraft:water
WetSponge
minecraft:wet_sponge
Wheat
minecraft:wheat
WhiteBanner
minecraft:white_banner
WhiteBed
minecraft:white_bed
WhiteCarpet
minecraft:white_carpet
WhiteConcrete
minecraft:white_concrete
WhiteConcretePowder
minecraft:white_concrete_powder
WhiteGlazedTerracotta
minecraft:white_glazed_terracotta
Fields
facing: HorizontalDirectionWhiteShulkerBox
minecraft:white_shulker_box
WhiteStainedGlass
minecraft:white_stained_glass
WhiteStainedGlassPane
minecraft:white_stained_glass_pane
WhiteTerracotta
minecraft:white_terracotta
WhiteTulip
minecraft:white_tulip
WhiteWallBanner
minecraft:white_wall_banner
Fields
facing: HorizontalDirectionWhiteWool
minecraft:white_wool
WitherRose
minecraft:wither_rose
WitherSkeletonSkull
minecraft:wither_skeleton_skull
WitherSkeletonWallSkull
minecraft:wither_skeleton_wall_skull
Fields
facing: HorizontalDirectionYellowBanner
minecraft:yellow_banner
YellowBed
minecraft:yellow_bed
YellowCarpet
minecraft:yellow_carpet
YellowConcrete
minecraft:yellow_concrete
YellowConcretePowder
minecraft:yellow_concrete_powder
YellowGlazedTerracotta
minecraft:yellow_glazed_terracotta
Fields
facing: HorizontalDirectionYellowShulkerBox
minecraft:yellow_shulker_box
YellowStainedGlass
minecraft:yellow_stained_glass
YellowStainedGlassPane
minecraft:yellow_stained_glass_pane
YellowTerracotta
minecraft:yellow_terracotta
YellowWallBanner
minecraft:yellow_wall_banner
Fields
facing: HorizontalDirectionYellowWool
minecraft:yellow_wool
ZombieHead
minecraft:zombie_head
ZombieWallHead
minecraft:zombie_wall_head
Fields
facing: HorizontalDirectionOther(GenericBlockState)
Any other unrecognized (possibly invalid) block state with a name and properties as strings.
Implementations
Sourceimpl BlockState
impl BlockState
Sourcepub fn as_generic(&self) -> GenericBlockState
pub fn as_generic(&self) -> GenericBlockState
Turn this block state into a
GenericBlockState.
This internally allocates new strings. It is used for implementing equality, as the
same block state can be represented by both a known variant and the Self::Other
variant.
Sourcepub fn map_color(&self) -> MapColor
pub fn map_color(&self) -> MapColor
Get the color this block’s default state has on maps.
Note: Every block state represented by the Self::Other variant will use
MapColor::None.