pub struct GenericBlockState {
pub name: Cow<'static, str>,
pub properties: HashMap<Cow<'static, str>, Cow<'static, str>>,
}Expand description
A generic block state that can represent any possible block state by storing the name and properties as strings.
Fields
name: Cow<'static, str>The id of this block, e.g. minecraft:air.
properties: HashMap<Cow<'static, str>, Cow<'static, str>>The properties of this block state as a map from names to values.